<?php
/**
 * Contains a list of all custom shortcodes and corresponding functions defined for Suffusion.
 * This file is included in functions.php
 *
 * @package Suffusion
 * @subpackage Functions
 */

add_shortcode('suffusion-categories', 'suffusion_sc_list_categories');
add_shortcode('suffusion-the-year', 'suffusion_sc_the_year');
add_shortcode('suffusion-site-link', 'suffusion_sc_site_link');
add_shortcode('suffusion-the-author', 'suffusion_sc_the_author');
add_shortcode('suffusion-the-post', 'suffusion_sc_the_post');
add_shortcode('suffusion-login-url', 'suffusion_sc_login_url');
add_shortcode('suffusion-logout-url', 'suffusion_sc_logout_url');
add_shortcode('suffusion-loginout', 'suffusion_sc_loginout');
add_shortcode('suffusion-register', 'suffusion_sc_register');
add_shortcode('suffusion-adsense', 'suffusion_sc_ad');
add_shortcode('suffusion-tag-cloud', 'suffusion_sc_tag_cloud');

function suffusion_sc_list_categories($attr) {
	if ($attr['title_li']) {
		$attr['title_li'] = suffusion_shortcode_string_to_bool($attr['title_li']);
	}
	if ($attr['hierarchical']) {
		$attr['hierarchical'] = suffusion_shortcode_string_to_bool($attr['hierarchical']);
	}
	if ($attr['use_desc_for_title']) {
		$attr['use_desc_for_title'] = suffusion_shortcode_string_to_bool($attr['use_desc_for_title']);
	}
	if ($attr['hide_empty']) {
		$attr['hide_empty'] = suffusion_shortcode_string_to_bool($attr['hide_empty']);
	}
	if ($attr['show_count']) {
		$attr['show_count'] = suffusion_shortcode_string_to_bool($attr['show_count']);
	}
	if ($attr['show_last_update']) {
		$attr['show_last_update'] = suffusion_shortcode_string_to_bool($attr['show_last_update']);
	}

	$attr['child_of'] = (int)$attr['child_of'];
	$attr['depth'] = (int)$attr['depth'];
	$attr['echo'] = false;

	$output = wp_list_categories( $attr );

	return $output;
}

function suffusion_sc_the_year() {
    return date('Y');
}

function suffusion_sc_site_link() {
    return '<a class="site-link" href="'.get_bloginfo('url').'" title="'.get_bloginfo('name').'" rel="home">'.get_bloginfo('name').'</a>';
}

function suffusion_sc_the_author($attr) {
    global $social_networks;
    $display = $attr['display'];
    $id = get_the_author_id();
    if ($id) {
        if ($display) {
            switch ($display) {
                case 'author':
                    return get_the_author();
                case 'modified-author':
                    return get_the_modified_author();
                case 'description':
                    return get_the_author_meta('description', $id);
                case 'login':
                    return get_the_author_meta('user_login', $id);
                case 'first-name':
                    return get_the_author_meta('first_name', $id);
                case 'last-name':
                    return get_the_author_meta('last_name', $id);
                case 'nickname':
                    return get_the_author_meta('nickname', $id);
                case 'id':
                    return get_the_author_meta('ID', $id);
                case 'url':
                    return get_the_author_meta('user_url', $id);
                case 'email':
                    return get_the_author_meta('user_email', $id);
                case 'link':
                    if (get_the_author_meta('user_url', $id)) {
                        return '<a href="'.get_the_author_meta('user_url', $id).'" title="'.get_the_author().'" rel="external">'.get_the_author().'</a>';
                    }
                    else {
                        return get_the_author();
                    }
                case 'aim':
                    return get_the_author_meta('aim', $id);
                case 'yim':
                    return get_the_author_meta('yim', $id);
                case 'posts':
                    return get_the_author_posts();
                case 'posts-url':
                    return get_author_posts_url(get_the_author_meta('ID'));
            }
            if ($social_networks[$display]) {
                return get_the_author_meta($display, $id);
            }
        }
        else {
            return get_the_author();
        }
    }
}

function suffusion_sc_the_post($attr) {
	global $post;
	$display = $attr['display'];
	$id = $post->ID;
	if ($id) {
		switch ($display) {
			case 'id':
				return $id;
			case 'title':
				return get_the_title($id);
			case 'permalink':
				return get_permalink($id);
			default:
				return get_the_title($id);
		}
	}
}

function suffusion_sc_login_url($attr) {
	return wp_login_url($attr['redirect']);
}

function suffusion_sc_logout_url($attr) {
	return wp_logout_url($attr['redirect']);
}

function suffusion_sc_loginout($attr) {
	if (!is_user_logged_in())
		$link = '<a href="' . esc_url(wp_login_url($attr['redirect'])) . '">' . __('Log in') . '</a>';
	else
		$link = '<a href="' . esc_url(wp_logout_url($attr['redirect'])) . '">' . __('Log out') . '</a>';

	$filtered = apply_filters('loginout', $link);
	return $filtered;
}

function suffusion_sc_register($attr) {
	$before = $attr['before'] ? $attr['before'] : '<li>';
	$after = $attr['after'] ? $attr['after'] : '</li>';
	if (!is_user_logged_in()) {
		if (get_option('users_can_register') )
			$link = $before . '<a href="' . site_url('wp-login.php?action=register', 'login') . '">' . __('Register') . '</a>' . $after;
		else
			$link = '';
	} else {
		$link = $before . '<a href="' . admin_url() . '">' . __('Site Admin') . '</a>' . $after;
	}

	$filtered = apply_filters('register', $link);
	return $filtered;
}

function suffusion_sc_ads($attr) {
	$params = array('client', 'slot', 'width', 'height');
	$provider = 'google';
	$provider_type = 'syndication';
	$service = 'ad';
	$service_type = 'page';
	$ret = "<div id='".$service."sense'>\n<script type='text/javascript'><!--\n";
	foreach ($params as $var) {
		$ret .= "\t".$provider."_".$service."_$var = '".$attr[$var]."';\n";
	}
	$ret .= "//-->\n<script>\n";
	$service_url = "http://".$service_type.$service."2.$provider$provider_type/$service_type$service/show_{$service}s.js";
	$ret .= "<script type='text/javascript' src='$service_url'></script>\n";
	$ret .= "</div>\n";
	return $ret;
}

function suffusion_sc_tag_cloud($attr) {
	$attr['smallest'] = (int)$attr['smallest'];
	$attr['largest'] = (int)$attr['largest'];
	$attr['number'] = (int)$attr['largest'];
	$attr['echo'] = false;
	return wp_tag_cloud($attr);
}

function suffusion_shortcode_string_to_bool($value) {
	if ($value == 'true' || $value == 'TRUE' || $value == '1') {
        return true;
    }
	else if ($value == 'false' || $value == 'FALSE' || $value == '0') {
        return false;
    }
	else {
        return $value;
    }
}

?>